<?php
// $Id: theme-settings.php,v 1.1.2.1 2009/03/25 23:33:28 rhache Exp $

// Settings for the Layoutstudio MYTHEME theme

// Include the definition of layoutstudio_settings() and layoutstudio_theme_get_default_settings().
include_once './' . drupal_get_path('theme', 'layoutstudio') . '/theme-settings.php';

/**
 * Implementation of THEMEHOOK_settings() function.
 *
 * @param $saved_settings
 *   An array of saved settings for this theme.
 * @return
 *   A form array.
 */
function MYTHEME_settings($saved_settings) {
	
  // Get the default values from the .info file.
  $defaults = layoutstudio_theme_get_default_settings('MYTHEME');

  // Merge the saved variables and their default values.
  $settings = array_merge($defaults, $saved_settings);

  /*
   * Create the form using Forms API: http://api.drupal.org/api/6
   */
  $form = array();
  
  $form['layoutstudio_layouts'] = array(
    '#type' => 'fieldset',
    '#title' => t('Select Layout'),
    '#description' => t('<p>Choose a site layout for the Primary, Secondary and Tertiary regions.<p>
      <p style="margin-bottom: 0;">Color reference for Primary, Secondary & Tertiary regions:</p>
      <ul class="color-reference layouts">
            <li class="primary-region">Primary</li>
            <li class="secondary-region">Secondary</li>
            <li class="tertiary-region">Tertiary</li>
      </ul class="color-reference">
    '),
    '#collapsible' => FALSE,
  );
  
  $layout_path = drupal_get_path("theme","MYTHEME")."/css/layouts";
  $form['layoutstudio_layouts']['layoutstudio_layout'] = array(
    '#type' => 'radios',              
    '#options' => array(
      "layout1" => t('<strong>Layout #1</strong>') . '<div class="layout-example layout-1"><div class="secondary-region"></div><div class="primary-region">1</div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>Three column layout with secondary on the left and tertiary on the right of the main content area.</p>'),
      "layout2" => t('<strong>Layout #2</strong>') . '<div class="layout-example layout-2"><div class="tertiary-region"></div><div class="primary-region">2</div><div class="secondary-region"></div></div>' . t('<p class="layout-type")>Three column layout with tertiary on the left and secondary on the right of the main content area.</p>'),
      "layout3" => t('<strong>Layout #3</strong>') . '<div class="layout-example layout-3"><div class="primary-region">3</div><div class="secondary-region"></div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>Three column layout with secondary and tertiary to the right of the main content area.</p>'),
      "layout4" => t('<strong>Layout #4</strong>') . '<div class="layout-example layout-4"><div class="primary-region">4</div><div class="tertiary-region"></div><div class="secondary-region"></div></div>' . t('<p class="layout-type")>Three column layout with tertiary and secondary to the right of the main content area.</p>'),
      "layout5" => t('<strong>Layout #5</strong>') . '<div class="layout-example layout-5"><div class="secondary-region"></div><div class="tertiary-region"></div><div class="primary-region">5</div></div>' . t('<p class="layout-type")>Three column layout with secondary and tertiary on the left of the main content area.</p>'),
      "layout6" => t('<strong>Layout #6</strong>') . '<div class="layout-example layout-6"><div class="tertiary-region"></div><div class="secondary-region"></div><div class="primary-region">6</div></div>' . t('<p class="layout-type")>Three column layout with tertiary and secondary on the left of the main content area.</p>'),
      "layout7" => t('<strong>Layout #7</strong>') . '<div class="layout-example layout-7"><div class="primary-region">7</div><div class="secondary-region"></div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>Secondary and tertiary as two columns below main content area.</p>'),
      "layout8" => t('<strong>Layout #8</strong>') . '<div class="layout-example layout-8"><div class="primary-region">8</div><div class="secondary-region"></div><div class="tertiary-region"></div></div>' . t('<p class="layout-type")>No columns. Primary, secondary and tertiary display full width in semantic order.</p>'),
    ),
    '#default_value' => $settings['layoutstudio_layout'],
    '#attributes' => array('class' => 'layouts'),
  );

  $form['layoutstudio_dimensions'] = array(
    '#type' => 'fieldset',
    '#title' => t('Set Dimensions'),
    '#description' => t('<p>Choose dimensions for a Page and for the Secondary and Tertiary regions of the site.'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['layoutstudio_dimensions']['layoutstudio_page_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Page width'),
    '#description' => t('Enter the desired width of the page, in pixels.'),
    '#required' => TRUE,
    '#default_value' => $settings['layoutstudio_page_width'],
    '#field_suffix' => t('px'),
  );

  $form['layoutstudio_dimensions']['layoutstudio_secondary_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Secondary region width'),
    '#description' => t('Enter the desired width of the Secondary region, in pixels.'),
    '#required' => FALSE,
    '#default_value' => $settings['layoutstudio_secondary_width'],
    '#field_suffix' => t('px'),
  );

  $form['layoutstudio_dimensions']['layoutstudio_tertiary_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Tertiary region width'),
    '#description' => t('Enter the desired width of the Tertiary region, in pixels.'),
    '#required' => FALSE,
    '#default_value' => $settings['layoutstudio_tertiary_width'],
    '#field_suffix' => t('px'),
  );
  
  /* -- Delete this line if you want to use this setting
  $form['MYTHEME_example'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Use this sample setting'),
    '#default_value' => $settings['MYTHEME_example'],
    '#description'   => t("This option doesn't do anything; it's just an example."),
  );
  // */

  drupal_add_js(
    "
    Drupal.behaviors.layoutstudioThemeSettings = function(context) {
      $('input[name=layoutstudio_layout]').change(function() {
        if ($(this).attr('checked')) {
          var layout = $(this).attr('value');
          
          if (layout == 'layout7') {
            $('#edit-layoutstudio-secondary-width-wrapper').show();
            $('#edit-layoutstudio-tertiary-width-wrapper').hide();
          }
          else if (layout == 'layout8') {
            $('#edit-layoutstudio-secondary-width-wrapper').hide();
            $('#edit-layoutstudio-tertiary-width-wrapper').hide();
          }
          else {
            $('#edit-layoutstudio-secondary-width-wrapper').show();
            $('#edit-layoutstudio-tertiary-width-wrapper').show();
          }
        }
      });
    }
    ",
    "inline"
  );

  // Add the base theme's settings.
  $form += layoutstudio_settings($saved_settings, $defaults);

  // Return the form
  return $form;
}
